"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addCompareScreenshotCommand = void 0;
const constants_1 = require("./constants");
const cypressScreenshotOptions = {
    log: true,
    blackout: [],
    capture: 'fullPage',
    clip: null,
    disableTimersAndAnimations: true,
    padding: null,
    scale: false,
    overwrite: true,
    onBeforeScreenshot: null,
    onAfterScreenshot: null
};
function addCompareScreenshotCommand(defaultScreenshotOptions) {
    Cypress.Commands.add('compareScreenshot', { prevSubject: 'optional' }, () => {
        const actualScreenshotPath = `${Cypress.spec.relative}/${Cypress.currentTest.title}${constants_1.ACTUAL_SUFFIX}${constants_1.SCREENSHOT_EXT}`
            .replace(/^cypress\/e2e\//, '');
        const screenshotOptions = {
            ...cypressScreenshotOptions,
            ...defaultScreenshotOptions
        };
        let screenshotPath = 'sss';
        cy.screenshot({
            ...screenshotOptions,
            onAfterScreenshot($el, props) {
                screenshotPath = props.path;
            }
        }).then(() => {
            cy.task('odiff:compare', {
                screenshotPath,
                actualScreenshotPath
            }).then((result) => {
                if (result !== true) {
                    throw new Error(result);
                }
            });
        });
    });
}
exports.addCompareScreenshotCommand = addCompareScreenshotCommand;
