"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.addCompareScreenshotPlugin = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const odiff_bin_1 = require("odiff-bin");
const constants_1 = require("./constants");
let CYPRESS_SCREENSHOT_DIR;
// let ALWAYS_GENERATE_DIFF
function setupScreenshotPath(config) {
    // use cypress default path as fallback
    CYPRESS_SCREENSHOT_DIR =
        (config || {}).screenshotsFolder || 'cypress/screenshots';
}
async function compareScreenshotsTask(args) {
    const actualAbsolutePath = path_1.default.join(CYPRESS_SCREENSHOT_DIR, args.actualScreenshotPath);
    fs_1.default.renameSync(args.screenshotPath, actualAbsolutePath);
    const expectedAbsolutePath = actualAbsolutePath.replace(constants_1.ACTUAL_SUFFIX, constants_1.EXPECTED_SUFFIX);
    const diffAbsolutePath = actualAbsolutePath.replace(constants_1.ACTUAL_SUFFIX, constants_1.DIFF_SUFFIX);
    if (fs_1.default.existsSync(expectedAbsolutePath)) {
        const compareResult = await (0, odiff_bin_1.compare)(actualAbsolutePath, expectedAbsolutePath, diffAbsolutePath);
        switch (compareResult.reason) {
            case "layout-diff":
                return "Screenshots does not have the same layout";
            case "pixel-diff":
                return `Screenshots does not match. ${compareResult.diffCount} pixels difference (${compareResult.diffPercentage}%)`;
            case "file-not-exists":
                return `File was not found ${compareResult.file}`;
        }
    }
    else {
        fs_1.default.copyFileSync(actualAbsolutePath, expectedAbsolutePath);
    }
    return true;
}
function addCompareScreenshotPlugin(on, config) {
    setupScreenshotPath(config);
    on('task', {
        'odiff:compare': async (args) => compareScreenshotsTask(args)
    });
}
exports.addCompareScreenshotPlugin = addCompareScreenshotPlugin;
